@@ -84,7 +84,7 @@ dataUrl = "http://ilthermo.boulder.nist.gov/ILT2/ilset"
 
 def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     #JOAO
-    global prp, params
+    global prp, params, prop2key   
     #JOAO
     """ Starts a query on the Ionic Liquids Database from NIST.
 
